==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/ctabbar.h <==
/***************************************************************************
                          ctabbar.h - manages tab bar
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Mon Nov 11 2003
    copyright            : (C) 2003 by Vladimir Lazarenko
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTABBAR_H
#define CTABBAR_H

#include <qtabbar.h>

class KPopupMenu;

class cTabBar : public QTabBar
{
   Q_OBJECT
public:
  cTabBar(QWidget *parent, const char *name = 0);
  ~cTabBar();
protected:
  enum PopupIDs
  {
    Rename = 0,
    Disconnect,
    Reconnect,
    CloseTab
  };
  void contextMenuEvent(QContextMenuEvent *cevt);

  KPopupMenu *popup;

signals:
  void closeTab();
  void reConnect();
  void disConnect();


};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/ctabbar.h <==
/***************************************************************************
                          ctabbar.h - manages tab bar
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Mon Nov 11 2003
    copyright            : (C) 2003 by Vladimir Lazarenko
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTABBAR_H
#define CTABBAR_H

#include <qtabbar.h>

class KPopupMenu;

class cTabBar : public QTabBar
{
   Q_OBJECT
public:
  cTabBar(QWidget *parent, const char *name = 0);
  ~cTabBar();
protected:
  enum PopupIDs
  {
    Rename = 0,
    Disconnect,
    Reconnect,
    CloseTab
  };
  void contextMenuEvent(QContextMenuEvent *cevt);

  KPopupMenu *popup;

signals:
  void closeTab();
  void reConnect();
  void disConnect();


};

#endif
